@@ -1,20 +1,17 @@
 #line 1 "inc/Module/Install/Can.pm - lib/Module/Install/Can.pm"
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Can.pm $ $Author: ingy $
-# $Revision: #5 $ $Change: 1377 $ $DateTime: 2003/03/20 15:11:54 $ vim: expandtab shiftwidth=4
-
 package Module::Install::Can;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
 $VERSION = '0.01';
+
 use strict;
+use Config ();
+use File::Spec ();
+use ExtUtils::MakeMaker ();
 
 # check if we can run some command
 sub can_run {
     my ($self, $cmd) = @_;
 
-    require Config;
-    require File::Spec;
-    require ExtUtils::MakeMaker;
-
     my $_cmd = $cmd;
     return $_cmd if (-x $_cmd or $_cmd = MM->maybe_command($_cmd));
 
@@ -28,9 +25,14 @@ sub can_run {
 
 sub can_cc {
     my $self = shift;
-    require Config;
-    my $cc = $Config::Config{cc} or return;
-    $self->can_run($cc);
+    my @chunks = split(/ /, $Config::Config{cc}) or return;
+
+    # $Config{cc} may contain args; try to find out the program part
+    while (@chunks) {
+        return $self->can_run("@chunks") || (pop(@chunks), next);
+    }
+
+    return;
 }
 
 1;
